<?php

namespace Ig\IgCookies\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2016 Sven Burkert <bedienung@sbtheke.de>, SBTheke web development
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use Ig\IgCookies\Domain\Repository\LogRepository;
use TYPO3\CMS\Backend\Template\Components\ButtonBar;
use TYPO3\CMS\Backend\Utility\BackendUtility;
use TYPO3\CMS\Backend\View\BackendTemplateView;
use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
use TYPO3\CMS\Core\Imaging\Icon;
use TYPO3\CMS\Core\Imaging\IconFactory;
use TYPO3\CMS\Core\Page\PageRenderer;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Mvc\View\ViewInterface;

/**
 * @package cookies
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */

class LogBackendController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {
  /**
   * @var string
   */
  protected $defaultViewObjectName = BackendTemplateView::class;

  /**
   * @var BackendTemplateView
   */
  protected $view;

  /**
   * @var \Ig\IgCookies\Domain\Repository\LogRepository
   */
  public $logRepository = null;

  protected function initializeView(ViewInterface $view)
  {
    $this->logRepository = GeneralUtility::makeInstance(LogRepository::class);
    $this->registerButtons();
  }

  /**
   * Registers the DocHeader buttons
   */
  protected function registerButtons()
  {
    $buttonBar = $this->view->getModuleTemplate()->getDocHeaderComponent()->getButtonBar();
    $currentRequest = $this->request;
    $moduleName = $currentRequest->getPluginName();
    $getVars = $this->request->getArguments();
    $extensionName = $currentRequest->getControllerExtensionName();
    if (count($getVars) === 0) {
      $modulePrefix = strtolower('tx_' . $extensionName . '_' . $moduleName);
      $getVars = ['id', 'M', $modulePrefix];
    }
    $shortcutButton = $buttonBar->makeShortcutButton()
      ->setModuleName($moduleName)
      ->setGetVariables($getVars);
    $buttonBar->addButton($shortcutButton);
}



  /**
   * action list: list cookies
   *
   * @return void
   */
  public function listAction() {
    //    $lang = $this->getLanguageService();
    $this->moduleTemplate=$this->view->getModuleTemplate();
    $this->iconFactory = GeneralUtility::makeInstance(IconFactory::class);

    //$this->moduleTemplate->getPageRenderer()->loadJquery();
    $this->getPageRenderer=GeneralUtility::makeInstance(PageRenderer::class);
    $this->getPageRenderer->loadRequireJsModule('TYPO3/CMS/IgCookies/ToggleSearchToolbox');

    $searchButton = $this->moduleTemplate->getDocHeaderComponent()->getButtonBar()->makeLinkButton();
                $searchButton
		  ->setHref('#')
		  ->setClasses('ig-cookies-toggle-search-toolbox')
		  //		  ->setTitle($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:labels.title.searchIcon'))
		  ->setTitle('Search')
		  ->setIcon($this->iconFactory->getIcon('actions-search', Icon::SIZE_SMALL));
		$this->moduleTemplate->getDocHeaderComponent()->getButtonBar()->addButton(
											  $searchButton,
											  ButtonBar::BUTTON_POSITION_LEFT,
											                  90
											  );



    $searchString = $this->request->hasArgument('searchString') ? $this->request->getArgument('searchString') : '';
    $logs = $this->logRepository->findBySearch($searchString);
    $this->view->assign('logs', $logs);
    $this->view->assign('searchString', $searchString);
  }

}
