<?php

namespace Ig\IgCookies\Controller;

use TYPO3\CMS\Core\Utility\GeneralUtility;
use Psr\Http\Message\ResponseInterface;
use TYPO3\CMS\Core\Localization\LanguageServiceFactory;


/**
 * @package cookies
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class MainController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController
{
    protected $languageFile = 'LLL:EXT:ig_cookies/Resources/Private/Language/locallang.xlf';
    protected $labelKeys = ['title', 'description'];
    /**
     * action cookie: display info to accept cookies
     *
     * @return void
     */
    public function cookieAction(): ResponseInterface
    {
        if ($this->settings['mode'] == 'configurable') {
            $cookieCategories = array_filter(GeneralUtility::trimExplode(',', $this->settings['cookieCategories']));
            $services = array_filter($this->settings['services']);
            $servicesArray = [];

            if ($services['languageFile']) {
                $this->languageFile = $services['languageFile'];
                unset($services['languageFile']);
            }
            foreach ($services as $service) {
                $arr = [];
                $arr['name'] = trim($service['name']);
                $this->getTranslatedLabels($service, $arr);
                if ($service['sub']) {
                    if (is_array($service['sub'])) {
                        $subService = [];
                        foreach ($service['sub'] as $sub) {
                            $subService['name'] = trim($sub['name']);
                            $this->getTranslatedLabels($sub, $subService);
                            $arr['sub'][] = $subService;
                        }
                    } else {
                        $arr['sub'] = $service['sub'];
                    }
                }
                $servicesArray[] = $arr;
            }
            $cookieCategoriesJson = json_encode($cookieCategories);
            $servicesJson = json_encode($servicesArray);
            $this->view->assign('services', $servicesArray);
            $this->view->assign('servicesJson', $servicesJson);
            $this->view->assign('cookieCategories', $cookieCategories);
            $this->view->assign('cookieCategoriesJson', $cookieCategoriesJson);
        }
        /*
	// Falls Action nicht gecacht
	if($_COOKIE['ig_cookies_accepted']==1) {
 	  return FALSE;
        }
      */
        return $this->htmlResponse($this->view->render());
    }

    public function getTranslatedLabels($service, &$arr)
    {
        foreach ($this->labelKeys as $label) {
            if ($service[$label]) {
                $ll = trim($service[$label]);
                if (substr($ll, 0, 8) == 'LLL:EXT:') {
                    $arr[$label] = $this->translate($ll);
                } else if (strpos($ll, '.') && !strpos($ll, ' ')) {
                    $arr[$label] = $this->translate($this->languageFile . ':' . $ll);
                } else {
                    $arr[$label] = $ll;
                }
            }
        }
    }

    public function settingsAction()
    {
        $cookieCategories = array_filter(GeneralUtility::trimExplode(',', $this->settings['cookieCategories']));
        $this->view->assign('cookieCategories', $cookieCategories);
    }
    private static function translate(string $lll): string
    {
        $languageServiceFactory = GeneralUtility::makeInstance(
            LanguageServiceFactory::class
        );
        $request = $GLOBALS['TYPO3_REQUEST'];
        $languageService = $languageServiceFactory->createFromSiteLanguage(
            $request->getAttribute('language')
                ?? $request->getAttribute('site')->getDefaultLanguage()
        );
        return $languageService->sL($lll);
    }
}
