class IgConsentManager {
    constructor(config) {
        const _defaults = {
            containerId: "#ig_consent_container",
            baseCookieName: "IgConsentManager_"
        };
        this.config = Object.assign(_defaults, config);
        this.consents = {};
        this.watchers = new Set([]);
        this.cookieBannerElement = document.querySelector(this.config.containerId);
        this.loadConsents();
        // wait for async cookies
        setTimeout(() => {
            this.notify(this.consents);
        }, 0);
    }
    loadConsents() {
        // get json array of categories
        let cookieCategories = this.cookieBannerElement.dataset.categories;
        // parse json to array fallback
        let cookieCategoriesArray = JSON.parse(cookieCategories);
        this.consents = cookieCategoriesArray.reduce((obj, consent) => { obj[consent] = false; return obj; }, {});
        // services
        let servicesArray = JSON.parse(this.cookieBannerElement.dataset.services);
        this.consents = servicesArray.reduce((obj, consent) => {
            if (consent['sub']) {
                Object.values(consent['sub']).forEach(subName => {
                    obj[subName] = false;
                });
            } else {
                obj[consent['name']] = false;
            }
            return obj;
        }, {});
        // get site localStorage Items
        Object.keys(this.consents).forEach(name => {
            let item = localStorage.getItem(this.config.baseCookieName + name);
            if (item) {
                this.consents[name] = item;
            }
        });
    }
    watch(watcher) {
        if (!this.watchers.has(watcher)) {
            this.watchers.add(watcher);
        }
        if (watcher.hasOwnProperty('init')) {
            watcher.init(this.consents);
        }
    }
    unwatch(watcher) {
        if (this.watchers.has(watcher)) {
            this.watchers.delete(watcher);
        }
    }
    update() {
        this.loadConsents();
        this.notify(this.consents);
    }
    notify(data) {
        this.watchers.forEach((watcher) => {
            watcher.update(data)
        });
    }
    getConsent(name) {
        return this.consents[name] || false;
    }

}
const igConsentManager = new IgConsentManager();
// add IgConsentManager to window object
window.IgConsentManager = igConsentManager;
if (typeof window.igJs !== 'undefined') {
    window.igJs.add('IgConsentManager', igConsentManager);
}