(function () {
    let localStorageBaseName = 'IgConsentManager_';
    let serviceCategoriesElement = document.getElementById('ig_consent_container');
    let servicesArray = JSON.parse(serviceCategoriesElement.dataset.services);
    let services = [];
    servicesArray.forEach(service => {
        let name = service['name'];
        if (service['sub']) {
            Object.values(service['sub']).forEach(subName => {
                services.push(subName);
            });
        } else {
            services.push(name);
        }
    });
    let prefix = '';
    let logPending = false;

    // Ugly but the consent banner is hidden in the code and I need to only get the cookie settings plugin if it is on the page
    if (document.getElementsByClassName('ig_consent_settings').length) {
        prefix = '.ig_consent_settings ';
    }
    if (document.getElementsByClassName('cookieCategory').length) {
        selectServiceCategories();
    }

    if (!document.getElementsByClassName('ig_consent_settings').length && !localStorage.getItem(localStorageBaseName + 'hide')) {
        showCookieConsent();
    }

    document.querySelector('.ig_consent_needed')?.addEventListener('click', function (e) {
        e.preventDefault();
        removeAllServices();
        acceptNeededServices();
        hideCookieConsent();
        logAccept(this);
    });
    let ig_consent_all = document.querySelectorAll('.ig_consent_all');
    if (ig_consent_all.length) {
        ig_consent_all.forEach(btn => {
            btn.addEventListener('click', function (e) {
                e.preventDefault();
                removeAllServices();
                acceptAllServices();
                hideCookieConsent();
                logAccept(this);
            });
        });
    }

    document.querySelector('.ig_consent_save')?.addEventListener('click', function (e) {
        e.preventDefault();
        removeAllServices();
        saveCookieSettings();
        hideCookieConsent();
        logAccept(this);
    });

    document.querySelector('.ig_consent_settings_button').addEventListener('click', function (e) {
        e.preventDefault();
        document.querySelector('#ig_consent_inner').classList.add('showSettings');
        document.querySelector('.ig-cookie-settings-popup').classList.add('show');
        document.querySelector('.ig-cookie-settings-popup-simple').classList.remove('show');
    });
    document.querySelector('.ig_consent_close').addEventListener('click', function (e) {
        e.preventDefault();
        document.querySelector('#ig_consent_inner').classList.remove('showSettings');
        document.querySelector('.ig-cookie-settings-popup').classList.remove('show');
        document.querySelector('.ig-cookie-settings-popup-simple').classList.add('show');
    });

    function showCookieConsent() {
        document.querySelector("#ig_consent_container").style.display = 'block';
        document.querySelector("body").classList.add('ig_consent');
    }

    function hideCookieConsent() {
        localStorage.setItem(localStorageBaseName + 'hide', true);
        document.querySelector("#ig_consent_container").style.display = 'none';
        document.querySelector("body").classList.remove('ig_consent');
    }

    function sendSettingsForm() {
        if (document.querySelector('.ig_consent_settings')) {
            document.querySelector('.ig_consent_settings form').submit();
        }
    }

    function removeAllServices() {
        services.forEach(function (service) {
            localStorage.removeItem(localStorageBaseName + service);
            callOptOutFunctions(service);
        });
    }
    function acceptAllServices() {
        services.forEach(function (service) {
            let checkboxes = document.querySelectorAll(prefix + '.cookieCategory-' + service + ' input[type="checkbox"]');
            checkboxes.forEach(function (checkbox) {
                checkbox.checked = true;
                checkbox.setAttribute('checked', true);
            });
            localStorage.setItem(localStorageBaseName + service, true);
            callOptInFunctions(service);
        });
    }
    function acceptNeededServices() {
        localStorage.setItem(localStorageBaseName + 'needed', true);
        callOptInFunctions('needed');
    }

    function saveCookieSettings() {
        document.querySelectorAll(prefix + '.cookieCategory input[type="checkbox"]:checked').forEach(function (checkbox) {
            let cookieCategory = checkbox.value;
            let cookieName = localStorageBaseName + cookieCategory;
            let expires = document.querySelector("#ig_consent_container").dataset.expires;
            if (!expires) {
                expires = 365;
            }
            //Services.set(cookieName, true, { expires: +expires, path: '/', domain: domain });
            localStorage.setItem(cookieName, true);
            callOptInFunctions(cookieCategory);
        });
    }

    function selectServiceCategories() {
        document.querySelectorAll(prefix + '.cookieCategory input[type="checkbox"]').forEach(function (checkbox) {
            let cookieCategory = checkbox.value;
            let cookieName = localStorageBaseName + cookieCategory;
            let parent = checkbox.dataset?.parent;
            if (parent) {
                checkbox.addEventListener('click', () => {
                    let selectedParent = document.getElementById(parent);
                    let selectedCheckbox = selectedParent.getElementsByTagName('input')[0];
                    selectedCheckbox.checked = checkbox.checked;
                });
            }
            if (localStorage.getItem(cookieName)) {
                checkbox.checked = true;
                checkbox.setAttribute('checked', true);
                callOptInFunctions(cookieCategory);
            }
        });
    }

    function callOptInFunctions(cookieCategory) {
        if (typeof window.igServicesOptInFunctions !== 'undefined') {
            let optInFunctionsForCategory = window.igServicesOptInFunctions[cookieCategory];
            if (typeof optInFunctionsForCategory !== 'undefined') {
                for (let j = 0; j < optInFunctionsForCategory.length; j++) {
                    optInFunctionsForCategory[j]();
                }
            }
        }
    }

    function callOptOutFunctions(cookieCategory) {
        if (typeof window.igServicesOptOutFunctions !== 'undefined') {
            let optOutFunctionsForCategory = window.igServicesOptOutFunctions[cookieCategory];
            if (typeof optOutFunctionsForCategory !== 'undefined') {
                for (let j = 0; j < optOutFunctionsForCategory.length; j++) {
                    optOutFunctionsForCategory[j]();
                }
            }
        }
    }

    function logAccept(element) {
        let logUrl = element.dataset.page;
        let categories = [];
        document.querySelectorAll(prefix + '.cookieCategory input[type="checkbox"]:checked').forEach(function (checkbox) {
            categories.push(checkbox.value);
        });

        if (logUrl) {
            if (!logPending) {
                logPending = true;
                let xhr = new XMLHttpRequest();
                xhr.open('POST', logUrl, true);
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                xhr.onreadystatechange = function () {
                    if (xhr.readyState === 4 && xhr.status === 200) {
                        logPending = false;
                        sendSettingsForm();
                    }
                };
                xhr.send('categories=' + encodeURIComponent(JSON.stringify(categories)));
            }
        } else {
            sendSettingsForm();
        }
        if (!window.IgConsentManager) {
            console.log('window.IgConsentManager is not defined. Is plugin.ig_consent.settings.delayedTags set?');
        } else {
            window.IgConsentManager?.update();
        }
    }
})();